---
jupytext:
  text_representation:
    extension: .md
    format_name: myst
    format_version: 0.13
    jupytext_version: 1.14.5
---

```{code-cell}
:tags: [remove-input]

import intake
import ciofs_hindcast_report as chr
import hvplot.pandas  # noqa
import ocean_model_skill_assessor as omsa
import pandas as pd
import cmocean.cm as cmo
import holoviews as hv
from holoviews import opts
```

(page:ctd_profiles_usgs_boem)=
# CTD Profiles (USGS BOEM): across Cook Inlet

* CTD profiles - USGS BOEM
* ctd_profiles_usgs_boem
* One-off CTD profiles from 2016 to 2021 in July

USGS Cook Inlet fish and bird survey CTD profiles.
    
CTD profiles collected in Cook Inlet from 2016-2021 by Mayumi Arimitsu as part of BOEM sponsored research on fish and bird distributions in Cook Inlet. The profiles are collected in July for the years 2016-2021.

The scientific project is described here: https://www.usgs.gov/centers/alaska-science-center/science/cook-inlet-seabird-and-forage-fish-study#overview.




```{dropdown} Dataset metadata

|    |    Dataset | featuretype   | key_variables    |   maxLatitude |   maxLongitude | maxTime             |   minLatitude |   minLongitude | minTime             | urlpath                                                                 |
|---:|-----------:|:--------------|:-----------------|--------------:|---------------:|:--------------------|--------------:|---------------:|:--------------------|:------------------------------------------------------------------------|
|  0 | 2016102001 | profile       | ['temp', 'salt'] |       60.2743 |       -152.356 | 2016-07-17 11:16:00 |       60.2743 |       -152.356 | 2016-07-17 11:16:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
|  1 | 2016106001 | profile       | ['temp', 'salt'] |       59.8774 |       -152.579 | 2016-07-18 16:13:00 |       59.8774 |       -152.579 | 2016-07-18 16:13:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
|  2 | 2016120001 | profile       | ['temp', 'salt'] |       60.3062 |       -152.192 | 2016-07-17 08:33:00 |       60.3062 |       -152.192 | 2016-07-17 08:33:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
|  3 | 2016122201 | profile       | ['temp', 'salt'] |       60.1779 |       -151.915 | 2016-07-17 15:56:00 |       60.1779 |       -151.915 | 2016-07-17 15:56:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
|  4 | 2016123001 | profile       | ['temp', 'salt'] |       60.057  |       -152.524 | 2016-07-16 08:12:00 |       60.057  |       -152.524 | 2016-07-16 08:12:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
|  5 | 2016123002 | profile       | ['temp', 'salt'] |       60.1052 |       -152.241 | 2016-07-16 11:11:00 |       60.1052 |       -152.241 | 2016-07-16 11:11:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
|  6 | 2016125001 | profile       | ['temp', 'salt'] |       59.9135 |       -152.194 | 2016-07-14 14:43:00 |       59.9135 |       -152.194 | 2016-07-14 14:43:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
|  7 | 2016126001 | profile       | ['temp', 'salt'] |       59.8026 |       -152.757 | 2016-07-18 19:19:00 |       59.8026 |       -152.757 | 2016-07-18 19:19:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
|  8 | 2016126002 | profile       | ['temp', 'salt'] |       59.8295 |       -152.538 | 2016-07-19 11:15:00 |       59.8295 |       -152.538 | 2016-07-19 11:15:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
|  9 | 2016205701 | profile       | ['temp', 'salt'] |       59.6646 |       -151.233 | 2016-07-23 14:10:00 |       59.6646 |       -151.233 | 2016-07-23 14:10:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 10 | 2016206001 | profile       | ['temp', 'salt'] |       59.5644 |       -151.393 | 2016-07-29 10:23:00 |       59.5644 |       -151.393 | 2016-07-29 10:23:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 11 | 2016221001 | profile       | ['temp', 'salt'] |       59.6698 |       -151.985 | 2016-07-28 11:22:00 |       59.6698 |       -151.985 | 2016-07-28 11:22:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 12 | 2016223001 | profile       | ['temp', 'salt'] |       59.5834 |       -151.446 | 2016-07-24 09:39:00 |       59.5834 |       -151.446 | 2016-07-24 09:39:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 13 | 2016223002 | profile       | ['temp', 'salt'] |       59.5713 |       -151.716 | 2016-07-24 12:10:00 |       59.5713 |       -151.716 | 2016-07-24 12:10:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 14 | 2016224001 | profile       | ['temp', 'salt'] |       59.5006 |       -151.889 | 2016-07-26 11:25:00 |       59.5006 |       -151.889 | 2016-07-26 11:25:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 15 | 2016225001 | profile       | ['temp', 'salt'] |       59.4217 |       -152.025 | 2016-07-26 18:55:00 |       59.4217 |       -152.025 | 2016-07-26 18:55:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 16 | 2016226001 | profile       | ['temp', 'salt'] |       59.3211 |       -152.102 | 2016-07-27 10:49:00 |       59.3211 |       -152.102 | 2016-07-27 10:49:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 17 | 2017101001 | profile       | ['temp', 'salt'] |       60.358  |       -152.214 | 2017-07-26 08:52:00 |       60.358  |       -152.214 | 2017-07-26 08:52:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 18 | 2017103001 | profile       | ['temp', 'salt'] |       60.1284 |       -152.493 | 2017-07-25 09:49:00 |       60.1284 |       -152.493 | 2017-07-25 09:49:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 19 | 2017120001 | profile       | ['temp', 'salt'] |       60.3292 |       -152.177 | 2017-07-26 13:12:00 |       60.3292 |       -152.177 | 2017-07-26 13:12:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 20 | 2017122001 | profile       | ['temp', 'salt'] |       60.231  |       -152.285 | 2017-07-26 14:38:00 |       60.231  |       -152.285 | 2017-07-26 14:38:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 21 | 2017123001 | profile       | ['temp', 'salt'] |       60.0473 |       -152.52  | 2017-07-23 07:29:00 |       60.0473 |       -152.52  | 2017-07-23 07:29:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 22 | 2017124001 | profile       | ['temp', 'salt'] |       59.9828 |       -152.263 | 2017-07-27 10:56:00 |       59.9828 |       -152.263 | 2017-07-27 10:56:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 23 | 2017125001 | profile       | ['temp', 'salt'] |       59.919  |       -152.27  | 2017-07-22 12:41:00 |       59.919  |       -152.27  | 2017-07-22 12:41:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 24 | 2017125002 | profile       | ['temp', 'salt'] |       59.9439 |       -151.941 | 2017-07-22 16:08:00 |       59.9439 |       -151.941 | 2017-07-22 16:08:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 25 | 2017201001 | profile       | ['temp', 'salt'] |       59.6637 |       -151.801 | 2017-07-31 11:03:00 |       59.6637 |       -151.801 | 2017-07-31 11:03:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 26 | 2017204001 | profile       | ['temp', 'salt'] |       59.6447 |       -151.282 | 2017-07-20 11:57:00 |       59.6447 |       -151.282 | 2017-07-20 11:57:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 27 | 2017205001 | profile       | ['temp', 'salt'] |       59.6727 |       -151.197 | 2017-07-19 15:35:00 |       59.6727 |       -151.197 | 2017-07-19 15:35:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 28 | 2017206001 | profile       | ['temp', 'salt'] |       59.6599 |       -151.224 | 2017-07-19 11:39:00 |       59.6599 |       -151.224 | 2017-07-19 11:39:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 29 | 2017207001 | profile       | ['temp', 'salt'] |       59.5196 |       -151.462 | 2017-07-20 16:40:00 |       59.5196 |       -151.462 | 2017-07-20 16:40:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 30 | 2017212001 | profile       | ['temp', 'salt'] |       59.3781 |       -151.891 | 2017-07-28 17:05:00 |       59.3781 |       -151.891 | 2017-07-28 17:05:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 31 | 2017214001 | profile       | ['temp', 'salt'] |       59.5773 |       -151.363 | 2017-07-18 15:56:00 |       59.5773 |       -151.363 | 2017-07-18 15:56:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 32 | 2017220001 | profile       | ['temp', 'salt'] |       59.7454 |       -151.998 | 2017-07-31 14:42:00 |       59.7454 |       -151.998 | 2017-07-31 14:42:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 33 | 2017223001 | profile       | ['temp', 'salt'] |       59.5842 |       -151.512 | 2017-07-30 10:12:00 |       59.5842 |       -151.512 | 2017-07-30 10:12:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 34 | 2017224001 | profile       | ['temp', 'salt'] |       59.4971 |       -151.843 | 2017-07-30 17:34:00 |       59.4971 |       -151.843 | 2017-07-30 17:34:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 35 | 2017225001 | profile       | ['temp', 'salt'] |       59.3998 |       -152.119 | 2017-07-28 12:41:00 |       59.3998 |       -152.119 | 2017-07-28 12:41:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 36 | 2018104001 | profile       | ['temp', 'salt'] |       60.0669 |       -152.537 | 2018-07-14 19:31:00 |       60.0669 |       -152.537 | 2018-07-14 19:31:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 37 | 2018120001 | profile       | ['temp', 'salt'] |       60.2993 |       -152.223 | 2018-07-17 11:20:00 |       60.2993 |       -152.223 | 2018-07-17 11:20:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 38 | 2018121001 | profile       | ['temp', 'salt'] |       60.2658 |       -152.178 | 2018-07-17 16:39:00 |       60.2658 |       -152.178 | 2018-07-17 16:39:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 39 | 2018122001 | profile       | ['temp', 'salt'] |       60.166  |       -152.476 | 2018-07-15 18:53:00 |       60.166  |       -152.476 | 2018-07-15 18:53:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 40 | 2018123001 | profile       | ['temp', 'salt'] |       60.0947 |       -151.961 | 2018-07-15 14:06:00 |       60.0947 |       -151.961 | 2018-07-15 14:06:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 41 | 2018124001 | profile       | ['temp', 'salt'] |       59.9949 |       -152.297 | 2018-07-18 10:10:00 |       59.9949 |       -152.297 | 2018-07-18 10:10:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 42 | 2018125001 | profile       | ['temp', 'salt'] |       59.8945 |       -151.986 | 2018-07-18 14:30:00 |       59.8945 |       -151.986 | 2018-07-18 14:30:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 43 | 2018126001 | profile       | ['temp', 'salt'] |       59.8347 |       -152.416 | 2018-07-19 11:23:00 |       59.8347 |       -152.416 | 2018-07-19 11:23:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 44 | 2018203001 | profile       | ['temp', 'salt'] |       59.5806 |       -151.52  | 2018-07-12 17:20:00 |       59.5806 |       -151.52  | 2018-07-12 17:20:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 45 | 2018203002 | profile       | ['temp', 'salt'] |       59.5905 |       -151.423 | 2018-07-25 09:26:00 |       59.5905 |       -151.423 | 2018-07-25 09:26:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 46 | 2018205001 | profile       | ['temp', 'salt'] |       59.6932 |       -151.157 | 2018-07-24 15:53:00 |       59.6932 |       -151.157 | 2018-07-24 15:53:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 47 | 2018208001 | profile       | ['temp', 'salt'] |       59.5375 |       -151.518 | 2018-07-13 17:48:00 |       59.5375 |       -151.518 | 2018-07-13 17:48:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 48 | 2018214002 | profile       | ['temp', 'salt'] |       59.5746 |       -151.339 | 2018-07-13 11:28:00 |       59.5746 |       -151.339 | 2018-07-13 11:28:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 49 | 2018221001 | profile       | ['temp', 'salt'] |       59.6566 |       -151.881 | 2018-07-26 20:01:00 |       59.6566 |       -151.881 | 2018-07-26 20:01:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 50 | 2018223001 | profile       | ['temp', 'salt'] |       59.5818 |       -151.473 | 2018-07-23 11:19:00 |       59.5818 |       -151.473 | 2018-07-23 11:19:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 51 | 2018223002 | profile       | ['temp', 'salt'] |       59.5737 |       -151.73  | 2018-07-25 16:34:00 |       59.5737 |       -151.73  | 2018-07-25 16:34:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 52 | 2018225001 | profile       | ['temp', 'salt'] |       59.4071 |       -152.014 | 2018-07-27 14:49:00 |       59.4071 |       -152.014 | 2018-07-27 14:49:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 53 | 2019106001 | profile       | ['temp', 'salt'] |       59.8465 |       -152.807 | 2019-07-21 10:03:00 |       59.8465 |       -152.807 | 2019-07-21 10:03:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 54 | 2019121001 | profile       | ['temp', 'salt'] |       60.1817 |       -152.209 | 2019-07-19 09:35:00 |       60.1817 |       -152.209 | 2019-07-19 09:35:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 55 | 2019122001 | profile       | ['temp', 'salt'] |       60.1561 |       -152.379 | 2019-07-19 11:59:00 |       60.1561 |       -152.379 | 2019-07-19 11:59:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 56 | 2019123001 | profile       | ['temp', 'salt'] |       60.0269 |       -151.982 | 2019-07-19 13:32:00 |       60.0269 |       -151.982 | 2019-07-19 13:32:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 57 | 2019125001 | profile       | ['temp', 'salt'] |       59.928  |       -152.179 | 2019-07-17 12:43:00 |       59.928  |       -152.179 | 2019-07-17 12:43:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 58 | 2019126001 | profile       | ['temp', 'salt'] |       59.8979 |       -151.898 | 2019-07-21 17:38:00 |       59.8979 |       -151.898 | 2019-07-21 17:38:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 59 | 2019205001 | profile       | ['temp', 'salt'] |       59.6756 |       -151.205 | 2019-07-28 11:24:00 |       59.6756 |       -151.205 | 2019-07-28 11:24:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 60 | 2019210001 | profile       | ['temp', 'salt'] |       59.4996 |       -151.735 | 2019-07-26 12:20:00 |       59.4996 |       -151.735 | 2019-07-26 12:20:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 61 | 2019221001 | profile       | ['temp', 'salt'] |       59.6465 |       -152.216 | 2019-07-22 13:47:00 |       59.6465 |       -152.216 | 2019-07-22 13:47:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 62 | 2019223001 | profile       | ['temp', 'salt'] |       59.5795 |       -151.4   | 2019-07-24 13:01:00 |       59.5795 |       -151.4   | 2019-07-24 13:01:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 63 | 2019223002 | profile       | ['temp', 'salt'] |       59.5726 |       -151.765 | 2019-07-27 16:45:00 |       59.5726 |       -151.765 | 2019-07-27 16:45:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 64 | 2019226001 | profile       | ['temp', 'salt'] |       59.3545 |       -152.231 | 2019-07-27 11:06:00 |       59.3545 |       -152.231 | 2019-07-27 11:06:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 65 | 2021105001 | profile       | ['temp', 'salt'] |       60.0328 |       -152.547 | 2021-07-18 17:37:00 |       60.0328 |       -152.547 | 2021-07-18 17:37:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 66 | 2021122001 | profile       | ['temp', 'salt'] |       60.1651 |       -152.314 | 2021-07-20 15:17:00 |       60.1651 |       -152.314 | 2021-07-20 15:17:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 67 | 2021123001 | profile       | ['temp', 'salt'] |       60.0727 |       -152.062 | 2021-07-21 16:40:00 |       60.0727 |       -152.062 | 2021-07-21 16:40:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 68 | 2021124001 | profile       | ['temp', 'salt'] |       60.0058 |       -152.25  | 2021-07-21 11:20:00 |       60.0058 |       -152.25  | 2021-07-21 11:20:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 69 | 2021125001 | profile       | ['temp', 'salt'] |       59.8989 |       -151.97  | 2021-07-18 10:13:00 |       59.8989 |       -151.97  | 2021-07-18 10:13:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 70 | 2021126001 | profile       | ['temp', 'salt'] |       59.8513 |       -152.565 | 2021-07-23 10:20:00 |       59.8513 |       -152.565 | 2021-07-23 10:20:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 71 | 2021205001 | profile       | ['temp', 'salt'] |       59.7194 |       -151.104 | 2021-07-25 09:01:00 |       59.7194 |       -151.104 | 2021-07-25 09:01:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 72 | 2021210001 | profile       | ['temp', 'salt'] |       59.5051 |       -151.586 | 2021-07-27 19:09:00 |       59.5051 |       -151.586 | 2021-07-27 19:09:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 73 | 2021221001 | profile       | ['temp', 'salt'] |       59.667  |       -152.202 | 2021-07-30 15:41:00 |       59.667  |       -152.202 | 2021-07-30 15:41:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 74 | 2021223001 | profile       | ['temp', 'salt'] |       59.582  |       -151.579 | 2021-07-29 11:48:00 |       59.582  |       -151.579 | 2021-07-29 11:48:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 75 | 2021223002 | profile       | ['temp', 'salt'] |       59.5683 |       -151.419 | 2021-07-29 17:10:00 |       59.5683 |       -151.419 | 2021-07-29 17:10:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 76 | 2021224001 | profile       | ['temp', 'salt'] |       59.4972 |       -152.164 | 2021-07-26 14:43:00 |       59.4972 |       -152.164 | 2021-07-26 14:43:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |
| 77 | 2021226001 | profile       | ['temp', 'salt'] |       59.3349 |       -152.047 | 2021-07-27 12:25:00 |       59.3349 |       -152.047 | 2021-07-27 12:25:00 | https://researchworkspace.com/files/42202136/Arimitsu_CookInlet_CTD.csv |

```



```{code-cell}
:tags: [remove-input]

cat = intake.open_catalog(chr.CAT_NAME("ctd_profiles_usgs_boem"))
```

## Map of CTD Profiles
    

```{code-cell}
:tags: [remove-input]

getattr(chr.src.plot_dataset_on_map, "ctd_profiles_usgs_boem")("ctd_profiles_usgs_boem")
```


```{div} full-width
## 2016
```

+++

2016102001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2016102001'].plot.data()
```

2016106001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2016106001'].plot.data()
```

2016120001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2016120001'].plot.data()
```

2016122201
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2016122201'].plot.data()
```

2016123001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2016123001'].plot.data()
```

2016123002
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2016123002'].plot.data()
```

2016125001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2016125001'].plot.data()
```

2016126001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2016126001'].plot.data()
```

2016126002
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2016126002'].plot.data()
```

2016205701
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2016205701'].plot.data()
```

2016206001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2016206001'].plot.data()
```

2016221001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2016221001'].plot.data()
```

2016223001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2016223001'].plot.data()
```

2016223002
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2016223002'].plot.data()
```

2016224001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2016224001'].plot.data()
```

2016225001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2016225001'].plot.data()
```

2016226001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2016226001'].plot.data()
```


```{div} full-width
## 2017
```

+++

2017101001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2017101001'].plot.data()
```

2017103001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2017103001'].plot.data()
```

2017120001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2017120001'].plot.data()
```

2017122001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2017122001'].plot.data()
```

2017123001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2017123001'].plot.data()
```

2017124001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2017124001'].plot.data()
```

2017125001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2017125001'].plot.data()
```

2017125002
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2017125002'].plot.data()
```

2017201001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2017201001'].plot.data()
```

2017204001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2017204001'].plot.data()
```

2017205001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2017205001'].plot.data()
```

2017206001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2017206001'].plot.data()
```

2017207001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2017207001'].plot.data()
```

2017212001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2017212001'].plot.data()
```

2017214001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2017214001'].plot.data()
```

2017220001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2017220001'].plot.data()
```

2017223001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2017223001'].plot.data()
```

2017224001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2017224001'].plot.data()
```

2017225001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2017225001'].plot.data()
```


```{div} full-width
## 2018
```

+++

2018104001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2018104001'].plot.data()
```

2018120001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2018120001'].plot.data()
```

2018121001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2018121001'].plot.data()
```

2018122001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2018122001'].plot.data()
```

2018123001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2018123001'].plot.data()
```

2018124001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2018124001'].plot.data()
```

2018125001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2018125001'].plot.data()
```

2018126001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2018126001'].plot.data()
```

2018203001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2018203001'].plot.data()
```

2018203002
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2018203002'].plot.data()
```

2018205001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2018205001'].plot.data()
```

2018208001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2018208001'].plot.data()
```

2018214002
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2018214002'].plot.data()
```

2018221001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2018221001'].plot.data()
```

2018223001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2018223001'].plot.data()
```

2018223002
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2018223002'].plot.data()
```

2018225001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2018225001'].plot.data()
```


```{div} full-width
## 2019
```

+++

2019106001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2019106001'].plot.data()
```

2019121001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2019121001'].plot.data()
```

2019122001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2019122001'].plot.data()
```

2019123001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2019123001'].plot.data()
```

2019125001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2019125001'].plot.data()
```

2019126001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2019126001'].plot.data()
```

2019205001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2019205001'].plot.data()
```

2019210001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2019210001'].plot.data()
```

2019221001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2019221001'].plot.data()
```

2019223001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2019223001'].plot.data()
```

2019223002
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2019223002'].plot.data()
```

2019226001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2019226001'].plot.data()
```


```{div} full-width
## 2021
```

+++

2021105001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2021105001'].plot.data()
```

2021122001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2021122001'].plot.data()
```

2021123001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2021123001'].plot.data()
```

2021124001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2021124001'].plot.data()
```

2021125001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2021125001'].plot.data()
```

2021126001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2021126001'].plot.data()
```

2021205001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2021205001'].plot.data()
```

2021210001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2021210001'].plot.data()
```

2021221001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2021221001'].plot.data()
```

2021223001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2021223001'].plot.data()
```

2021223002
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2021223002'].plot.data()
```

2021224001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2021224001'].plot.data()
```

2021226001
        

```{code-cell}
:tags: [full-width, remove-input]

cat['2021226001'].plot.data()
```
